<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: *");

// Obtém o endereço IP do cliente
$ip = $_SERVER['REMOTE_ADDR'];

// Obtém o agente do usuário (navegador)
$user_agent = $_SERVER['HTTP_USER_AGENT'];

// Obtém o método da requisição (GET, POST, etc.)
$request_method = $_SERVER['REQUEST_METHOD'];

// Obtém o URI da requisição
$request_uri = $_SERVER['REQUEST_URI'];

// Grava as informações em um arquivo de log
$log_message = "IP: $ip - User Agent: $user_agent - Request Method: $request_method - Request URI: $request_uri\n";

// Caminho para o arquivo de log
$log_file = 'requests.log';

// Adiciona as informações ao arquivo de log
file_put_contents($log_file, $log_message, FILE_APPEND);


include_once __DIR__ . '/../../config/db-connection.php';
include_once __DIR__ . '/../../config/https_environment.php';
include_once __DIR__ . '/../../utils/utils.php';

//CHECK API KEY
test_header_key();

$json = file_get_contents('php://input');
    
$json = json_decode($json,true);

if(empty($json['id_user'])){
    http_response_code(400);
    die(json_encode([
        'debug' => 'id_user'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}
$id_user = mysqli_real_escape_string($conn,$json['id_user']);

if(empty($json['student_data'])){
    http_response_code(400);
    die(json_encode([
        'debug' => 'student_data'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}
$student_data = $json['student_data'];

if(isset($student_data['cpf'])){
    $cpf = mysqli_real_escape_string($conn,$student_data['cpf']);
}else{
    http_response_code(400);
    die(json_encode([
        'debug' => 'cpf'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

if(isset($student_data['name'])){
    $name = mysqli_real_escape_string($conn,$student_data['name']);
}else{
    http_response_code(400);
    die(json_encode([
        'debug' => 'name'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

if(isset($student_data['birth'])){
    $birth = mysqli_real_escape_string($conn,$student_data['birth']);
    $birth = str_replace('/','-',$birth);
    $birth = strtotime($birth);
    $birth = date('Y-m-d',$birth);
}else{
    http_response_code(400);
    die(json_encode([
        'debug' => 'birth'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

if(isset($student_data['email'])){
    $email = mysqli_real_escape_string($conn,$student_data['email']);
}else{
    http_response_code(400);
    die(json_encode([
        'debug' => 'email'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}
if(isset($student_data['phone'])){
    $phone = mysqli_real_escape_string($conn,$student_data['phone']);
}else{
    http_response_code(400);
    die(json_encode([
        'debug' => 'phone'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

if(isset($student_data['city'])){
    $city = mysqli_real_escape_string($conn,$student_data['city']);
}else{
    http_response_code(400);
    die(json_encode([
        'debug' => 'city'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

if(isset($student_data['state'])){
    $state = mysqli_real_escape_string($conn,$student_data['state']);
}else{
    http_response_code(400);
    die(json_encode([
        'debug' => 'state'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

if(isset($student_data['group'])){
    $group = mysqli_real_escape_string($conn,$student_data['group']);
    $group = intval($group);
    if($group != 0){
        $group = -1;
    }else{
        $group = 0;
    }
}else{
    $group = 0;
}


$sql_group = "SELECT id_group FROM `groups` WHERE `level` = {$group} LIMIT 1";
$result_group = mysqli_query($conn,$sql_group);
if(!$result_group){
    $error = mysqli_error($conn);
    http_response_code(500);
    mysqli_rollback($conn);
    mysqli_close($conn);
    die(json_encode([
        'debug_sql' => $error,
        'debug' => 'error getting group id',
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}
$row_group = mysqli_fetch_assoc($result_group);
$id_group = $row_group['id_group'];

$id_code = "null";
if(isset($student_data['code'])){
    $code = mysqli_real_escape_string($conn,$student_data['code']);
    $sql_code = "SELECT id_code FROM `codes` WHERE `label` = '{$code}' LIMIT 1";
    $result_code = mysqli_query($conn,$sql_code);

    if(!$result_code){
        $error = mysqli_error($conn);
        http_response_code(500);
        mysqli_rollback($conn);
        mysqli_close($conn);
        die(json_encode([
            'debug_sql' => $error,
            'debug' => 'error getting code id',
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }

    if(mysqli_num_rows($result_code) < 1){
        http_response_code(400);
        mysqli_rollback($conn);
        mysqli_close($conn);
        die(json_encode([
            'message' => 'O código de cadastro informado é inválido'
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }

    $row_code = mysqli_fetch_assoc($result_code);
    $id_code = '"' .$row_code['id_code'] . '"';

}

if(isset($student_data['password'])){
    $password = mysqli_real_escape_string($conn,$student_data['password']);
}

// TEST USER PERMITION

    $test_permition = test_permition($conn,$id_user,2);
    if($test_permition['status'] != 200){
        mysqli_close($conn);
        http_response_code(500);
        die(json_encode([
            'debug' => $test_permition
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }
    if(!$test_permition['response']['permition']){
        mysqli_close($conn);
        http_response_code(403);
        die(json_encode([
            'debug' => 'permition'
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }
    
//

$sql_verify = "SELECT id_user FROM users WHERE email = '{$email}';";

$result_verify = mysqli_query($conn,$sql_verify);
if(!$result_verify){
    $error = mysqli_error($conn);
    http_response_code(500);
    mysqli_rollback($conn);
    mysqli_close($conn);
    die(json_encode([
        'debug' => 'email verify',
        'debug_error' => $error
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

if(mysqli_num_rows($result_verify) > 0){
    $error = mysqli_error($conn);
    http_response_code(400);
    mysqli_rollback($conn);
    mysqli_close($conn);
    die(json_encode([
        'message' => 'O endereço de e-mail já está em uso.'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

$sql_create = "CALL sp_create_user('{$id_user}','{$id_group}',0,'{$cpf}','{$name}','{$email}','{$phone}', md5('{$password}'),'{$city}','{$state}',{$id_code},'{$birth}',1)";

$result_create = mysqli_query($conn,$sql_create);



if(!$result_create){
    $error = mysqli_error($conn);
    http_response_code(500);
    mysqli_rollback($conn);
    mysqli_close($conn);
    die(json_encode([
        'debug' => $error,
        'debug_sql' => $sql_create
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

mysqli_next_result($conn);

$ret = send_register_email($conn,$url_alt,$password,$name,$email);

if(!$ret){
    $error = mysqli_error($conn);
    http_response_code(500);
    mysqli_rollback($conn);
    mysqli_close($conn);
    die(json_encode([
        'debug' => $error
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

http_response_code(200);
mysqli_commit($conn);
mysqli_close($conn);

die();

?>

