<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: *");

include_once __DIR__ . '/../../config/db-connection.php';
include_once __DIR__ . '/../../config/https_environment.php';
include_once __DIR__ . '/../../utils/utils.php';

//CHECK API KEY
test_header_key();

// GET PARAMS
    $json = file_get_contents('php://input');
    
    $json = json_decode($json,true);

    if(empty($json['id_user'])){
        http_response_code(400);
        die(json_encode([
            'debug' => 'id_user'
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }
    $id_user = mysqli_real_escape_string($conn,$json['id_user']);

    if(empty($json['id_section'])){
        http_response_code(400);
        die(json_encode([
            'debug' => 'id_section'
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }
    $id_section = mysqli_real_escape_string($conn,$json['id_section']);
    
       


//GET CONTENT DATA
    $sql_contents = "SELECT
    a.correct,
    a.status as has_answer,
    c.`order`,
    c.`id_section`,
    c.`id_content`,
    l.order as level_order,
    u.order as unit_order,
    u.id_unit,
    s.order as section_order,
    s.unrestricted,
    s.free_access
    FROM contents c
    INNER JOIN sections s ON c.id_section = s.id_section
    INNER JOIN units u ON u.id_unit = s.id_unit
    INNER JOIN `levels` l ON u.id_level = l.id_level
    LEFT JOIN answers a ON a.id_content = c.id_content AND a.id_user = '{$id_user}'
    WHERE s.id_section = '{$id_section}' AND
    c.status = 1
    ORDER BY c.order";
    $result_content = mysqli_query($conn,$sql_contents);
    if(!$result_content){
        http_response_code(500);
        die(json_encode([
            'debug' => 'erro na query, ' . $sql_contents
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }
    $json_contents = [];
    while($row_content = mysqli_fetch_assoc($result_content)){
        $id_content = $row_content['id_content'];
        $order_content = $row_content['order'];
        $answer = $row_content['has_answer'] == 1 ? true : false;
        $correct = $row_content['correct'];
        if($correct != null){
            $correct = $correct == 1 ? true : false;
        }
        $json_contents[$id_content] = [
            'id_content' => $id_content,
            'order'      => $order_content,
            'answer'     => $answer,
            'correct'    => $correct
        ];

        $level_order = $row_content['level_order'];
        $unit_order = $row_content['unit_order'];
        $section_order = $row_content['section_order'];
        $id_unit = $row_content['id_unit'];
        $section_unrestricted = $row_content['unrestricted'];
        $section_free_access = $row_content['free_access'];
    }
    
//TEST STUDENT GROUP PERMITION
    $sql_group      = "SELECT g.level, u.editor FROM users u INNER JOIN `groups` g USING(id_group) WHERE u.id_user = '{$id_user}';";
    $result_group   = mysqli_query($conn,$sql_group);

    if(!$result_group){
        $error = mysqli_error($conn);
        http_response_code(500);
        mysqli_close($conn);
        die(json_encode([
            'debug' => $error
        ],JSON_UNESCAPED_UNICODE));
    }
    $row_group = mysqli_fetch_assoc($result_group);
    $group_level = $row_group['level'];
    $editor = $row_group['editor'];

    if($section_free_access != 1){

        if($group_level == -1){
            if($section_free_access != 1){
                http_response_code(403);
                mysqli_close($conn);
                die(json_encode([
                    'debug' => 'user progress 403'
                ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
            }
        }
    }

// GET USER PROGRESS PERMITION
    $result_user_progress = get_user_progress($id_user,$url);

    if($result_user_progress['status'] != 200){
        http_response_code($result_user_progress['status']);
        die(json_encode([
            'debug' => $result_user_progress['debug']
        ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
    }

    $user_progress_json = $result_user_progress['response']['user_progress'];
    $user_unit_progress = json_decode($user_progress_json['unitProgress'],true);
    $user_progress = $user_progress_json['progress'];

// TEST USER PROGRESS PERMITION
    // EXECUTE TEST
        $res_last_content = get_last_content($conn);
        if($res_last_content['status'] != 200){
            mysqli_close($conn);
            die(json_encode([
                'debug' => 'last_content'
            ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
        }
        $last_content_object = $res_last_content['response'];
        
        if($last_content_object['level']['id'] != null){

            $last_user_progress_authorized = check_user_permission_material([
                'level' => $last_content_object['level']['order'],
                'unit' => $last_content_object['unit']['order'],
                'section' => $last_content_object['section']['order'],
                'content' => $last_content_object['content']['order']
            ],$user_progress);
    
            if(!$last_user_progress_authorized){
                if($section_unrestricted != 1){
                    if($group_level < 3 && $editor != 1){
                        $user_progress_authorized = check_user_permission_material([
                            'level' => $level_order,
                            'unit' => $unit_order,
                            'section' => $section_order,
                            'content' => 0,
                        ],$user_progress);
                    
                        if(!$user_progress_authorized){
                            http_response_code(403);
                            mysqli_close($conn);
                            die(json_encode([
                                'debug' => 'user progress 403'
                            ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
                        }
                    }
                }
            }
        
        }else{
            $last_user_progress_authorized = true;
        }
    
/////////////////

// TEST CONTENTS PERMITIONS
    foreach($json_contents as $content_data){

        $content_order = $content_data['order'];
        $id_content = $content_data['id_content'];
        
        if($group_level > 2 || $editor == 1){
            $json_contents[$id_content]['allow'] = true;
        }else{
            if(!$last_user_progress_authorized){
                $content_permition = check_user_permission_material([
                    'level' => $level_order,
                    'unit' => $unit_order,
                    'section' => $section_order,
                    'content' => $content_order
                ],$user_progress);
        
                $json_contents[$id_content]['allow'] = $content_permition;
            }else{
                $json_contents[$id_content]['allow'] = true;
            }
        }


    }
// END OPERARION
    http_response_code(200);
    mysqli_commit($conn);
    mysqli_close($conn);
    die(json_encode([
        'question_list' => $json_contents
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));

?>
